@@ -144,7 +144,7 @@ astr agetcwd (void);
 bool expand_path (astr path);
 astr compact_path (astr path);
 bool find_file (const char *filename);
-_Noreturn void zile_exit (int doabort);
+void _Noreturn zile_exit (int doabort);
 
 /* funcs.c ---------------------------------------------------------------- */
 void set_mark_interactive (void);
@@ -247,6 +247,7 @@ void term_move (size_t y, size_t x);
 void term_clrtoeol (void);
 void term_refresh (void);
 void term_clear (void);
+void term_addch (char c);
 void term_addstr (const char *s);
 void term_attrset (size_t attr);
 void term_beep (void);
@@ -262,6 +263,7 @@ castr term_minibuf_read (const char *prompt, const char *value, size_t pos,
                          Completion * cp, History * hp);
 
 /* term_redisplay.c ------------------------------------------------------- */
+void term_redraw_cursor (void);
 void term_redisplay (void);
 void term_finish (void);
 
