@@ -1,6 +1,6 @@
 /* Getting and ungetting key strokes
 
-   Copyright (c) 1997-2004, 2008-2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 1997-2004, 2008-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -21,9 +21,7 @@
 
 #include <config.h>
 
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
+#include <assert.h>
 
 #include "main.h"
 #include "extern.h"
@@ -38,14 +36,13 @@ lastkey (void)
 }
 
 /*
- * Get a keystroke, waiting for up to timeout 10ths of a second if
- * mode contains GETKEY_DELAYED, and translating it into a
- * keycode unless mode contains GETKEY_UNFILTERED.
+ * Get a keystroke, waiting for up to GETKEY_DELAYED ms, and translate
+ * it into a keycode.
  */
 size_t
-xgetkey (int mode, size_t timeout)
+getkey (int mode)
 {
-  _last_key = term_xgetkey (mode, timeout);
+  _last_key = term_getkey (mode);
 
   if (thisflag & FLAG_DEFINING_MACRO)
     add_key_to_cmd (_last_key);
@@ -53,24 +50,27 @@ xgetkey (int mode, size_t timeout)
   return _last_key;
 }
 
-/*
- * Wait for a keystroke indefinitely, and return the
- * corresponding keycode.
- */
 size_t
-getkey (void)
+getkey_unfiltered (int mode)
 {
-  return xgetkey (0, 0);
+  int key = term_getkey_unfiltered (mode);
+  assert (key >= 0);
+
+  _last_key = (size_t) key;
+  if (thisflag & FLAG_DEFINING_MACRO)
+    add_key_to_cmd (key);
+
+  return key;
 }
 
 /*
- * Wait for timeout 10ths if a second or until a key is pressed.
- * The key is then available with [x]getkey.
+ * Wait for GETKEY_DELAYED ms or until a key is pressed.  The key is
+ * then available with [x]getkey.
  */
 void
-waitkey (size_t timeout)
+waitkey (void)
 {
-  ungetkey (xgetkey (GETKEY_DELAYED, timeout));
+  ungetkey (getkey (GETKEY_DELAYED));
 }
 
 /*
