@@ -1,6 +1,6 @@
 /* Kill ring facility functions
 
-   Copyright (c) 2001, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 2001, 2003-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -28,41 +28,34 @@
 #include "main.h"
 #include "extern.h"
 
-static astr kill_ring_text;
+static estr kill_ring_text;
 
 static void
 maybe_free_kill_ring (void)
 {
   if (last_command () != F_kill_region)
-    {
-      if (kill_ring_text != NULL)
-        astr_delete (kill_ring_text);
-      kill_ring_text = NULL;
-    }
+    kill_ring_text.as = NULL;
 }
 
 static void
-kill_ring_push (astr as)
+kill_ring_push (estr es)
 {
-  if (kill_ring_text == NULL)
-    kill_ring_text = astr_new ();
-  astr_cat (kill_ring_text, as);
+  if (kill_ring_text.as == NULL)
+    kill_ring_text = estr_new_astr (astr_new ());
+  estr_cat (kill_ring_text, es);
 }
 
 static bool
-copy_or_kill_region (bool kill, Region * rp)
+copy_or_kill_region (bool kill, Region r)
 {
-  astr as = copy_text_block (get_region_start (rp), get_region_size (rp));
-
-  kill_ring_push (as);
-  astr_delete (as);
+  kill_ring_push (get_buffer_region (cur_bp, r));
 
   if (kill)
     {
       if (get_buffer_readonly (cur_bp))
         minibuf_error ("Read only text copied to kill ring");
       else
-        assert (delete_region (rp));
+        assert (delete_region (r));
     }
 
   set_this_command (F_kill_region);
@@ -71,48 +64,24 @@ copy_or_kill_region (bool kill, Region * rp)
   return true;
 }
 
-static bool
-kill_to_bol (void)
-{
-  bool ok = true;
-
-  if (!bolp ())
-    {
-      Region * rp = region_new ();
-      Point pt = get_buffer_pt (cur_bp);
-
-      set_region_size (rp, pt.o);
-      pt.o = 0;
-      set_region_start (rp, pt);
-
-      ok = copy_or_kill_region (true, rp);
-      free (rp);
-    }
-
-  return ok;
-}
-
 static bool
 kill_line (bool whole_line)
 {
   bool ok = true;
   bool only_blanks_to_end_of_line = false;
+  size_t cur_line_len = buffer_line_len (cur_bp, get_buffer_pt (cur_bp));
 
   if (!whole_line)
     {
-      Point cur_pt = get_buffer_pt (cur_bp);
-      astr cur_line = get_line_text (cur_pt.p);
       size_t i;
-
-      for (i = cur_pt.o; i < astr_len (cur_line); i++)
+      for (i = get_buffer_pt (cur_bp) - get_buffer_line_o (cur_bp); i < cur_line_len; i++)
         {
-          char c = astr_get (cur_line, i);
+          char c = get_buffer_char (cur_bp, get_buffer_line_o (cur_bp) + i);
           if (!(c == ' ' || c == '\t'))
             break;
         }
 
-      if (i == astr_len (cur_line))
-        only_blanks_to_end_of_line = true;
+      only_blanks_to_end_of_line = i == cur_line_len;
     }
 
   if (eobp ())
@@ -121,33 +90,21 @@ kill_line (bool whole_line)
       return false;
     }
 
-  undo_save (UNDO_START_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+  undo_start_sequence ();
 
   if (!eolp ())
-    {
-      Region * rp = region_new ();
-
-      set_region_start (rp, get_buffer_pt (cur_bp));
-      set_region_size (rp, astr_len (get_line_text (get_buffer_pt (cur_bp).p)) - get_buffer_pt (cur_bp).o);
-
-      ok = copy_or_kill_region (true, rp);
-      free (rp);
-    }
+    ok = copy_or_kill_region (true, region_new (get_buffer_pt (cur_bp), get_buffer_line_o (cur_bp) + cur_line_len));
 
   if (ok && (whole_line || only_blanks_to_end_of_line) && !eobp ())
     {
-      astr as;
-
-      if (!FUNCALL (delete_char))
+      if (FUNCALL (delete_char) == leNIL)
         return false;
 
-      as = astr_new_cstr ("\n");
-      kill_ring_push (as);
-      astr_delete (as);
+      kill_ring_push ((estr) {.as = astr_new_cstr ("\n"), .eol = get_buffer_eol (cur_bp)});
       set_this_command (F_kill_region);
     }
 
-  undo_save (UNDO_END_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+  undo_end_sequence ();
 
   return ok;
 }
@@ -185,12 +142,13 @@ with no argument.
     ok = bool_to_lisp (kill_line (bolp () && get_variable_bool ("kill-whole-line")));
   else
     {
-      undo_save (UNDO_START_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+      undo_start_sequence ();
       if (arg <= 0)
-        ok = bool_to_lisp (kill_to_bol ());
+        ok = bool_to_lisp (bolp () ||
+                           copy_or_kill_region (true, region_new (get_buffer_line_o (cur_bp), get_buffer_pt (cur_bp))));
       if (arg != 0 && ok == leT)
-        ok = execute_with_uniarg (true, arg, kill_whole_line, kill_line_backward);
-      undo_save (UNDO_END_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+        ok = execute_with_uniarg (false, arg, kill_whole_line, kill_line_backward);
+      undo_end_sequence ();
     }
 
   deactivate_mark ();
@@ -200,16 +158,15 @@ END_DEFUN
 static bool
 copy_or_kill_the_region (bool kill)
 {
-  Region * rp = region_new ();
   bool ok = false;
 
-  if (calculate_the_region (rp))
+  if (!warn_if_no_mark ())
     {
+      Region r = calculate_the_region ();
       maybe_free_kill_ring ();
-      ok = copy_or_kill_region (kill, rp);
+      ok = copy_or_kill_region (kill, r);
     }
 
-  free (rp);
   return ok;
 }
 
@@ -248,10 +205,10 @@ kill_text (int uniarg, Function mark_func)
     return leNIL;
 
   push_mark ();
-  undo_save (UNDO_START_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+  undo_start_sequence ();
   mark_func (uniarg, true, NULL);
   FUNCALL (kill_region);
-  undo_save (UNDO_END_SEQUENCE, get_buffer_pt (cur_bp), 0, 0);
+  undo_end_sequence ();
   pop_mark ();
 
   set_this_command (F_kill_region);
@@ -301,7 +258,7 @@ More precisely, reinsert the stretch of killed text most recently
 killed @i{or} yanked.  Put point at end, and set mark at beginning.
 +*/
 {
-  if (kill_ring_text == NULL)
+  if (kill_ring_text.as == NULL)
     {
       minibuf_error ("Kill ring is empty");
       return leNIL;
@@ -310,14 +267,8 @@ killed @i{or} yanked.  Put point at end, and set mark at beginning.
   if (warn_if_readonly_buffer ())
     return leNIL;
 
-  set_mark_interactive ();
-
-  undo_save (UNDO_REPLACE_BLOCK, get_buffer_pt (cur_bp), 0,
-             astr_len (kill_ring_text));
-  undo_nosave = true;
-  insert_astr (kill_ring_text);
-  undo_nosave = false;
-
+  FUNCALL (set_mark_command);
+  insert_estr (kill_ring_text);
   deactivate_mark ();
 }
 END_DEFUN
